EticaAI/HXL-Data-Science-file-formats/hxlm-js

# hxlm-js

(qdp->eng "Open the console log of your browser!")

## HDPbMiniman

### JavaScript

    // let HDP_DEBUG = true
    import { HDPbMiniman, HDPbL10n, HDPbLisp } from './bootstrapper/hdpb-minimam.mjs'

    // let HDP_DEBUG = true
    let bootstrapping = HDPbMiniman.bootstrapping()
    let ego = HDPbL10n.quis_sum()

    // HDP Language _bootstrapping_ based on you (_ego_)
    let hdp = new HDPbMiniman(bootstrapping, ego)

    // Output the current version of this library
    console.log("HDP Miniman version:", hdp.version)

    // Output what we can automate for you
    console.log("HDPbMiniman.EGO :", hdp.EGO)

    // This return an quick overview
    hdp.explanare().then(console.log).catch(console.error)

    // Return the Localization Knowledge Graph, when ready
    hdp.explanare('LKG').then(console.log).catch(console.error)

    // Return the Vocabulary Knowledge Graph, when ready
    hdp.explanare('VKG').then(console.log).catch(console.error)

### console.log

## Other quick links

- testum.html, (not yet fully autmated tests; both for browser and NodeJS enviroment)